<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Vadim Galaktionov CV 12-05-2019</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="name">
        <h1>Vadim Galaktionov</h1>
    </div>
    <dl class="personalia">
        <dt><strong>Phone:</strong></dt>
        <dd>+31 6 46842904</dd>
        <dt><strong>Email:</strong></dt>
        <dd>vadim@galaktionov.nl</dd>
        <dt><strong>Address:</strong></dt>
        <dd>Kangoeroestraat 71, 4817GA Breda</dd>
        <dt><strong>Nationality:</strong></dt>
        <dd>Dutch</dd>
    </dl>
    <br>
    <br>
    <br>
    <br>
    <br>
    <main>
        <h2>Work Experience</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="5">
                    <h3>Cross-sector Structural Improvement Engineer & Data Engineer @ ASML</h3><br>
                    
                    <em>Semiconductor equipment manufacturing</em>
                    
                </td>
                <td>September 2018 - present</td>
            </tr>
            
            <tr>
                <td colspan="6">
                    <p>Lead developer role in team developing a Python application for parsing, analyzing and pseudonymizing photolithography fab automation logs (Django, Pandas). Development of backend microservices (Java, Spring Boot) Collaborating with architect and project lead on requirements gathering, prioritizing, planning and estimation. Focus on improving team workflow through mentoring, code reviews, pair programming and tech presentations. Redesign and implementation of application GUI. Rotating scrum master role. Deployment of application onsite at customer lithography fab.</p>
                </td>
            </tr>
            
            
        </table>
        <h2>Education</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="5">
                    <h3>MSc Business Information Management</h3><br>
                    <em>University of Rotterdam</em>
                </td>
                <td>2015 - 2016</td>
            </tr>
            <tr>
                <td colspan="6">
                    <p>fooo the bar and ba the baz</p>
                </td>
            </tr>
            
        </table>
        <h2>Skills</h2>
        <table class="cvtable">
            
            <tr>
                <td>
                    <h3>computer</h3><br>
                </td>
            </tr>
            <tr>
                <td class="description">
                    <p>Foo, Bar, Baz</p>
                </td>
            </tr>
            
        </table>
        <h2>Projects</h2>
        <table class="cvtable">
            
            <tr>
                <td>
                    <h3>MSc Thesis - "On the Economic Value of Renewable Energy Cooperatives"</h3><br>
                </td>
            </tr>
            <tr>
                <td>
                    <p>fooo the bar and ba the baz</p>
                </td>
            </tr>
            
        </table>
        <h2>Other Activities</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="5">
                    <h3>Data Engineer</h3><br>
                    <em>Super cool</em>
                </td>
                <td>2015 - 2016</td>
            </tr>
            <tr>
                <td colspan="6">
                    <p>fooo the bar and ba the baz</p>
                </td>
            </tr>
            
        </table>
    </main>
</body>

</html>